Module: Jekyll

Defined in:
lib/tags/iffile.rb,
lib/tags/icon.rb,
lib/tags/logo.rb,
lib/tags/post.rb,
lib/tags/image.rb,
lib/tags/video.rb,
lib/tags/member.rb,
lib/tags/social.rb,
lib/filters/main.rb,
lib/tags/iffalsy.rb,
lib/tags/external.rb,
lib/tags/iftruthy.rb,
lib/tags/language.rb,
lib/tags/readtime.rb,
lib/tags/urlmatches.rb,
lib/tags/fake_comments.rb,
lib/hooks/parallel-build.rb,
lib/jekyll-uj-powertools.rb,
lib/tags/translation_url.rb,
lib/hooks/markdown-images.rb,
lib/generators/blog-taxonomy.rb,
lib/generators/dynamic-pages.rb,
lib/helpers/variable_resolver.rb,
lib/generators/inject-properties.rb,
lib/generators/limit-collections.rb

Overview

Limit Collections Generator Limits the number of documents in collections during development for faster builds

Usage in _config.dev.yml:

limit_collections:
  recipes: 50
  products: 20

By default, uses a seeded random sample for diverse selection across categories. To disable randomization and take first N documents:

limit_collections:
  recipes: 50
  products: 20
  randomize: false

Run Jekyll with: bundle exec jekyll serve –config _config.yml,_config.dev.yml

Defined Under Namespace

Modules: UJPowertools Classes: BlogTaxonomyGenerator, CategoryPage, DynamicCategoryPage, DynamicPagesGenerator, InjectProperties, LimitCollectionsGenerator, ParallelBuildGenerator, TagPage, UJCommentsTag, UJIconTag, UJImageTag, UJLanguageTag, UJLogoTag, UJMemberTag, UJPostTag, UJReadtimeTag, UJSocialTag, UJTranslationUrlTag, UJVideoTag